==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001/MP0118_GetGridHeaderData_001.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001}FUNCTION_REQUEST_INFO"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "function_REQUEST_INFO"
})
@XmlRootElement(name = "MP0118_GetGridHeaderData_001")
public class MP0118_GetGridHeaderData_001 {

    @XmlElement(name = "FUNCTION_REQUEST_INFO", required = true)
    protected FUNCTION_REQUEST_INFO function_REQUEST_INFO;

    /**
     * Gets the value of the function_REQUEST_INFO property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_INFO }
     *     
     */
    public FUNCTION_REQUEST_INFO getFUNCTION_REQUEST_INFO() {
        return function_REQUEST_INFO;
    }

    /**
     * Sets the value of the function_REQUEST_INFO property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_INFO }
     *     
     */
    public void setFUNCTION_REQUEST_INFO(FUNCTION_REQUEST_INFO value) {
        this.function_REQUEST_INFO = value;
    }

}

==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001/MP0118_GetGridHeaderData_001.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001}FUNCTION_REQUEST_INFO"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "function_REQUEST_INFO"
})
@XmlRootElement(name = "MP0118_GetGridHeaderData_001")
public class MP0118_GetGridHeaderData_001 {

    @XmlElement(name = "FUNCTION_REQUEST_INFO", required = true)
    protected FUNCTION_REQUEST_INFO function_REQUEST_INFO;

    /**
     * Obtient la valeur de la propriété function_REQUEST_INFO.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_INFO }
     *     
     */
    public FUNCTION_REQUEST_INFO getFUNCTION_REQUEST_INFO() {
        return function_REQUEST_INFO;
    }

    /**
     * Définit la valeur de la propriété function_REQUEST_INFO.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_INFO }
     *     
     */
    public void setFUNCTION_REQUEST_INFO(FUNCTION_REQUEST_INFO value) {
        this.function_REQUEST_INFO = value;
    }

}
